@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """ Stanley Flat File Blog Tool
     ---------------------------
     author: Glen Swinfield <glen.swinfied@gmail.com>
@@ -8,10 +9,10 @@ import yaml
 
 def parse_yaml(src_file):
     with open(src_file, 'r') as f:
-        blocks = f.read().split('---')
+        blocks = f.read().split('---', 2)
         if len(blocks) is not 3:
-            raise Exception("Content file could not be parsed")
+            raise Exception("Content file could not be parsed %s" % src_file)
         front_matter = yaml.load(blocks[1])
         content = blocks[2].strip()
 
-    return {'front_matter': front_matter, 'content': content}
+    return {'front_matter': front_matter, 'content': unicode(content, 'utf-8')}
