@@ -14,9 +14,8 @@ from twisted.internet import reactor
 
 from stanley.parser import parse_yaml
 from stanley.site import Site
-from stanley.compiler import Jinja2Compiler
 from stanley.config import Config
-from stanley import touch
+from stanley import fs
 
 
 def init(path):
@@ -27,7 +26,7 @@ def init(path):
     if not os.path.exists(basepath):
         os.makedirs(basepath)
     if not os.path.exists(path):
-        touch(path)
+        fs.touch(path)
     if not os.path.exists(os.path.join(basepath, 'content')):
         os.mkdir(os.path.join(basepath, 'content'))
 
@@ -48,11 +47,11 @@ def build(path, less):
     c = Config(path)
     s = Site(c, parse_yaml)
     # clear existing contents from destination directory
-    for root, dirs, files in os.walk(c.destdir + '/*'):
-        for f in files:
-            os.unlink(os.path.join(root, f))
-        for d in dirs:
-            shutil.rmtree(os.path.join(root, d))
+    try:
+        fs.rmdir(c.destdir)
+    except AttributeError:
+        pass
+    fs.mkdirs(c.destdir)
     s.build(less)
 
 
